# Command

* [setuptools コマンド覚書](https://qiita.com/JhonnyBravo/items/b8bae2578f07f31e4de7)

順番に処理される。

```
python setup.py sdist bdist_wheel
```

```{toctree}
build_py
build_ext
sdist
install
```

## extend

* [Python: セットアップスクリプト (setup.py) に自作のコマンドを追加する](https://blog.amedama.jp/entry/2015/09/17/224627)
* <https://jichu4n.com/posts/how-to-add-custom-build-steps-and-commands-to-setuppy/>
